==> haskell-pipes-http-1.0.5-55-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-2wL7CvJs4yQCbArdYzLiQ8
key: pipes-http-1.0.5-2wL7CvJs4yQCbArdYzLiQ8
license: BSD3
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Pipes.HTTP
abi: d0d5ecea11a2de5ee7eee59f3299ab1b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-2wL7CvJs4yQCbArdYzLiQ8
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    pipes-4.3.4-2oiWVQSy2yOC4qzO1fqRx0
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-client-tls-0.3.5.1-F4vZMRDuQRRoQ6MvR8sjD
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             pipes-4.3.4-2oiWVQSy2yOC4qzO1fqRx0=d25c29db3ec41534931cce86db61784e
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             http-client-tls-0.3.5.1-F4vZMRDuQRRoQ6MvR8sjD=7f8211b4304048840bd01c76431ffbde
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.5-58-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-LMLOgytmV989Nv7kyUuQWW
key: pipes-http-1.0.5-LMLOgytmV989Nv7kyUuQWW
license: BSD3
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Pipes.HTTP
abi: c236b1f72babd012ccdaba51844e5b8b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-LMLOgytmV989Nv7kyUuQWW
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    pipes-4.3.4-2oiWVQSy2yOC4qzO1fqRx0
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             pipes-4.3.4-2oiWVQSy2yOC4qzO1fqRx0=d25c29db3ec41534931cce86db61784e
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J=bfd2559218a81acc5cfe715436ea1e49
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
